@@ -102,6 +102,14 @@ class Config(object):
             'vllm_model': 'NousResearch/Meta-Llama-3-8B-Instruct',
             # ZMQ Frontend Specific
             'zmq_backend': 'tcp://localhost:11177',
+            # System messages
+            'system_message': '''\
+You are an excellent free software developer. You write high-quality code.
+You aim to provide people with professional and accurate information.
+You cherish software freedom. You obey the Debian Social Contract and the
+Debian Free Software Guidelines. You follow the Debian Policy. You must
+always cite resources in your response when applicable, and provide the
+URL links in plain text format in the response.'''
         }
         # the built-in defaults will be overridden by config file
         if not os.path.exists(home):
@@ -141,16 +149,3 @@ class Config(object):
 
     def __getattr__(self, index):
         return self.toml.__getitem__(index)
-
-
-########################
-# System Messages
-########################
-
-OPENAI_SYSTEM_MESSAGE = '''\
-You are an excellent free software developer. You write high-quality code.
-You aim to provide people with prefessional and accurate information.
-You cherrish software freedom. You obey the Debian Social Contract and the
-Debian Free Software Guideline. You follow the Debian Policy. You must
-always cite resources in your response when applicable, and provide the
-URL links in plain text format in the response.'''
