@@ -34,6 +34,7 @@ from rich.markdown import Markdown
 from rich.markup import escape
 from rich.text import Text
 from rich.padding import Padding
+from rich.panel import Panel
 from rich.style import Style as richStyle
 
 from . import defaults
@@ -215,8 +216,7 @@ class OpenAIFrontend(AbstractFrontend):
     NAME: str = 'OpenAIFrontend'
     debug: bool = False
     stream: bool = True
-    system_message: str = defaults.OPENAI_SYSTEM_MESSAGE
-
+    
     def __init__(self, args):
         super().__init__(args)
         try:
@@ -228,8 +228,8 @@ class OpenAIFrontend(AbstractFrontend):
                              base_url=args.openai_base_url)
         self.model = args.openai_model
         # XXX: some models do not support system messages yet. nor temperature.
-        if self.model not in ('o1-mini', 'o1-preview'):
-            self.session.append({"role": "system", "content": self.system_message})
+        if self.model not in ('o1-mini', 'o1-preview', 'o3-mini'):
+            self.session.append({"role": "system", "content": args.system_message})
             self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         else:
             self.kwargs = {}
@@ -267,15 +267,20 @@ class OpenAIFrontend(AbstractFrontend):
             if self.render_markdown:
                 with Live(Markdown('')) as live:
                     for chunk in completion:
-                        if chunk.choices[0].delta.content is None:
-                            continue
-                        piece = chunk.choices[0].delta.content
-                        if piece == '</think>' and think is not None:
-                            cursor = chunks
-                        elif piece == '<think>':
-                            cursor = think
+                        if hasattr(chunk.choices[0].delta, 'reasoning_content'):
+                            if chunk.choices[0].delta.reasoning_content:
+                                rpiece = chunk.choices[0].delta.reasoning_content
+                                think.append(rpiece)
+                        if chunk.choices[0].delta.content:
+                            piece = chunk.choices[0].delta.content
+                            if piece == '</think>' and len(think) > 0:
+                                cursor = chunks
+                            elif piece == '<think>':
+                                cursor = think
+                            else:
+                                cursor.append(piece)
                         else:
-                            cursor.append(piece)
+                            continue
                         # join chunks
                         buffer_think = ''.join(think)
                         part1 = Text(buffer_think)
@@ -287,20 +292,28 @@ class OpenAIFrontend(AbstractFrontend):
                         live.update(group, refresh=True)
             else:
                 for chunk in completion:
-                    if chunk.choices[0].delta.content is None:
+                    if chunk.choices[0].delta.reasoning_content:
+                        piece = chunk.choices[0].delta.reasoning_content
+                        think.append(piece)
+                        print(piece, end="", flush=True)
+                    if chunk.choices[0].delta.content:
+                        piece = chunk.choices[0].delta.content
+                        chunks.append(piece)
+                        print(piece, end="", flush=True)
+                    else:
                         continue
-                    piece = chunk.choices[0].delta.content
-                    chunks.append(piece)
-                    print(piece, end="", flush=True)
             generated_text = ''.join(chunks)
             if not generated_text.endswith('\n'):
                 print()
                 sys.stdout.flush()
         else:
+            reasoning_content = completion.choices[0].delta.reasoning_content
             generated_text = completion.choices[0].message.content
             if self.render_markdown:
+                console_stdout.print(Panel(Markdown(reasoning_content)))
                 console_stdout.print(Markdown(generated_text))
             else:
+                console_stdout.print(Panel(reasoning_content))
                 console_stdout.print(escape(generated_text))
         new_message = {'role': 'assistant', 'content': generated_text}
         self.update_session(new_message)
@@ -480,7 +493,7 @@ class XAIFrontend(OpenAIFrontend):
         from openai import OpenAI
         self.client = OpenAI(api_key=args.xai_api_key,
                              base_url='https://api.x.ai/v1/')
-        self.session.append({"role": "system", "content": self.system_message})
+        self.session.append({"role": "system", "content": args.system_message})
         self.model = args.xai_model
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
@@ -500,7 +513,7 @@ class NvidiaFrontend(OpenAIFrontend):
         from openai import OpenAI
         self.client = OpenAI(api_key=args.nvidia_api_key,
                              base_url=args.nvidia_base_url)
-        self.session.append({"role": "system", "content": self.system_message})
+        self.session.append({"role": "system", "content": args.system_message})
         self.model = args.nvidia_model
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
@@ -519,7 +532,7 @@ class LlamafileFrontend(OpenAIFrontend):
         from openai import OpenAI
         self.client = OpenAI(api_key='no-key-required',
                              base_url=args.llamafile_base_url)
-        self.session.append({"role": "system", "content": self.system_message})
+        self.session.append({"role": "system", "content": args.system_message})
         self.model = 'llamafile from https://github.com/Mozilla-Ocho/llamafile'
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
@@ -538,7 +551,7 @@ class OllamaFrontend(OpenAIFrontend):
         from openai import OpenAI
         self.client = OpenAI(api_key='no-key-required',
                              base_url=args.ollama_base_url)
-        self.session.append({"role": "system", "content": self.system_message})
+        self.session.append({"role": "system", "content": args.system_message})
         self.model = args.ollama_model
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
@@ -557,7 +570,7 @@ class LlamacppFrontend(OpenAIFrontend):
         from openai import OpenAI
         self.client = OpenAI(api_key='no-key-required',
                              base_url=args.llamacpp_base_url)
-        self.session.append({"role": "system", "content": self.system_message})
+        self.session.append({"role": "system", "content": args.system_message})
         self.model = 'model-is-specified-at-the-llama-server-arguments'
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
@@ -579,7 +592,7 @@ class DeepSeekFrontend(OpenAIFrontend):
         if args.deepseek_model not in ('deepseek-reasoner'):
             # see the usage recommendations at
             # https://huggingface.co/deepseek-ai/DeepSeek-R1
-            self.session.append({"role": "system", "content": self.system_message})
+            self.session.append({"role": "system", "content": args.system_message})
         self.model = args.deepseek_model
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
@@ -598,7 +611,7 @@ class vLLMFrontend(OpenAIFrontend):
         from openai import OpenAI
         self.client = OpenAI(api_key='your-vllm-api-key',
                              base_url=args.vllm_base_url)
-        self.session.append({"role": "system", "content": self.system_message})
+        self.session.append({"role": "system", "content": args.system_message})
         self.model = args.vllm_model
         self.kwargs = {'temperature': args.temperature, 'top_p': args.top_p}
         if args.verbose:
